@@ -34,7 +34,8 @@ class Metric:
 class _Stat:
     duration: float
     method: str
-    path: str
+    route: str
+    path_params: dict
     code: int
 
 
@@ -87,18 +88,23 @@ class HTTPMetricsCollector:
             if stat == self.QUEUE_END:
                 self.queue.task_done()
                 break
+
+            tags = dict(method=stat.method, route=stat.route, code=str(stat.code),
+                        bucket=self.get_bucket(stat.duration))
+            for k, v in stat.path_params.items():
+                tags[k] = v
+
             metric = Metric('http_duration',
                             fields={'seconds': round(stat.duration, 3)},
-                            tags=dict(method=stat.method, path=stat.path, code=str(stat.code),
-                                      bucket=self.get_bucket(stat.duration)))
+                            tags=tags)
             try:
                 self.send(metric)
             except Exception:
                 print(traceback.format_exc())
             self.queue.task_done()
 
-    def collect(self, duration, method, path, code):
-        stat = _Stat(duration, method, path, code)
+    def collect(self, duration, method, route, path_params, code):
+        stat = _Stat(duration, method, route, path_params, code)
         self.queue.put(stat, block=False)
 
     def shutdown(self):
