@@ -21,7 +21,25 @@ class HTTPMetricsMiddleware:
     def __call__(self, request):
         start_time = time.time()
         response = self.get_response(request)
+        route, path_params = self._get_route_and_path_params(request)
+
         self.collector.collect(duration=time.time() - start_time,
-                               method=request.method, path=request.path,
+                               method=request.method, route=route,
+                               path_params=path_params,
                                code=response.status_code)
+
         return response
+
+    @staticmethod
+    def _get_route_and_path_params(request):
+        route = '<unnamed route>'
+        params = {}
+
+        if hasattr(request, 'resolver_match'):
+            if request.resolver_match is not None:
+                if request.resolver_match.route is not None:
+                    route = request.resolver_match.route
+                if request.resolver_match.kwargs is not None:
+                    params = request.resolver_match.kwargs
+
+        return route, params
